declare type Raw = {
    /**
     * Components will not be grouped by their name if set to `true`
     */
    raw: true;
};
declare type NotRaw = {
    /**
     * Components will not be grouped by their name if set to `true`
     */
    raw?: false;
};
declare type Options = {
    /**
     * Glob pattern(s) to include
     */
    include: string | Array<string>;
    /**
     * Only include components from these imports
     * @example ['src/components', '@my/library']
     */
    from?: Array<string>;
    /**
     * Ignores sub-components if true, eg `<Foo.Bar />`
     */
    ignoreSubComponents?: boolean;
    /**
     * Truncates JS expressions in props to this length
     * @default 40
     */
    expressionLength?: number;
    /**
     * Components will not be grouped by their name if set to `true`
     * @default false
     */
    raw?: boolean;
};
declare type Prop = {
    value: string | boolean | number | null | undefined;
    name: string;
    expression: boolean;
};
export declare type Props = Array<Prop>;
export declare type Instance = {
    name: string;
    spread: boolean;
    props: Props;
    from?: string;
    location: {
        file: string;
        line: number;
        character: number;
    };
};
export declare type Result = {
    name: string;
    count: number;
    from?: 'indeterminate' | string;
    instances: Array<Instance>;
};
declare type Results<T> = T extends Raw ? Array<Instance> : Array<Result>;
export declare type Config = (Options & Raw) | (Options & NotRaw);
/**
 * Analyzes files for React component usage
 * @see https://github.com/jonambas/react-delver
 */
export declare function delve<TOptions extends Config>(config: TOptions): Results<TOptions>;
export {};
